==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/type_test/doc/TestOccuringChoice2.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.OccuringChoice2;


/**
 * <p>Java class for testOccuringChoice2 element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testOccuringChoice2">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types3}OccuringChoice2"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types3}OccuringChoice2"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testOccuringChoice2")
public class TestOccuringChoice2 {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected OccuringChoice2 x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected OccuringChoice2 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringChoice2 }
     *     
     */
    public OccuringChoice2 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringChoice2 }
     *     
     */
    public void setX(OccuringChoice2 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringChoice2 }
     *     
     */
    public OccuringChoice2 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringChoice2 }
     *     
     */
    public void setY(OccuringChoice2 value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/doc/TestOccuringChoice2.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.OccuringChoice2;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types3}OccuringChoice2"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types3}OccuringChoice2"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testOccuringChoice2")
public class TestOccuringChoice2 {

    @XmlElement(required = true)
    protected OccuringChoice2 x;
    @XmlElement(required = true)
    protected OccuringChoice2 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringChoice2 }
     *     
     */
    public OccuringChoice2 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringChoice2 }
     *     
     */
    public void setX(OccuringChoice2 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringChoice2 }
     *     
     */
    public OccuringChoice2 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringChoice2 }
     *     
     */
    public void setY(OccuringChoice2 value) {
        this.y = value;
    }

}
